fw: replace Link with forwarding hint

Forwarding now processes forwarding hint on Interests,
and no longer considers the Link object.

refs #4055

Change-Id: I0331687ee8ec31afa2f1a105e903670689647c4d
diff --git a/daemon/table/network-region-table.hpp b/daemon/table/network-region-table.hpp
index 663d2f5..22da902 100644
--- a/daemon/table/network-region-table.hpp
+++ b/daemon/table/network-region-table.hpp
@@ -1,6 +1,6 @@
 /* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
-/**
- * Copyright (c) 2014-2016,  Regents of the University of California,
+/*
+ * Copyright (c) 2014-2017,  Regents of the University of California,
  *                           Arizona Board of Regents,
  *                           Colorado State University,
  *                           University Pierre & Marie Curie, Sorbonne University,
@@ -41,16 +41,16 @@
 {
 public:
   /** \brief determines whether an Interest has reached a producer region
-   *  \param link the Link object on an Interest
+   *  \param forwardingHint forwarding hint of an Interest
    *  \retval true the Interest has reached a producer region
    *  \retval false the Interest has not reached a producer region
    *
    *  If any delegation names in the Link object is a prefix of any region name,
    *  the Interest has reached the producer region and should be forwarded according to ‎its Name;
    *  otherwise, the Interest should be forwarded according to the delegations.
    */
   bool
-  isInProducerRegion(const Link& link) const;
+  isInProducerRegion(const DelegationList& forwardingHint) const;
 };
 
 } // namespace nfd
@@ -41,16 +41,16 @@
    *  \retval false the Interest has not reached a producer region
    *
-   *  If any delegation names in the Link object is a prefix of any region name,
+   *  If any delegation name in the forwarding hint is a prefix of any region name,
    *  the Interest has reached the producer region and should be forwarded according to ‎its Name;
@@ -41,16 +41,16 @@
    *  the Interest has reached the producer region and should be forwarded according to ‎its Name;
-   *  otherwise, the Interest should be forwarded according to the delegations.
+   *  otherwise, the Interest should be forwarded according to the forwarding hint.
    */
   bool